@@ -7,6 +7,7 @@ from rich import box
 from rich.prompt import Confirm
 from rich.table import Table
 
+from ._checks import pre_run_check
 from .console import console
 from .read_filter import get_filter_count
 
@@ -55,6 +56,11 @@ def get_args():
         metavar="",
         default="pipeline",
     )
+    parser.add_argument(
+        "--skip-init-check",
+        help=argparse.SUPPRESS,
+        action="store_true",
+    )
 
     # extract specific parameters
     extract_parser = parser.add_argument_group(title="extract options")
@@ -175,6 +181,9 @@ def get_args():
 
     args = parser.parse_args()
 
+    if not args.skip_init_check:
+        pre_run_check()
+
     return {
         "main": {
             "sourcedir": args.sourcedir,
